%% PHYSTWO estimations of Phytoplanckton Functional Types 

clear all
close all

cd /home/geo/Dropbox/PHYSTWO

% Load matrices
load A20140205.L2_LAC_OC.mat

% color map
h2=[ 0.5  0.5 0.5; 0 0 1; 0 1 1; 1 1 0; 1 0 0; .5 0 0];

%-----------------------------------------------------------
% PFT estimation using not adjusted orthomodels
model=1
[PFTunad, U1, U2, modevar, U1S, U2S, ai, pftnom]=modis_phystwo(Rrs412,Rrs443,Rrs469,Rrs488,Rrs531,Rrs547,Rrs555, aot, chl, model);

figure 
subplot(2,2,2);
pcolor(lon, lat, PFTunad); shading flat;caxis([1 6])
title(['PHYSTWO PFT from unajusted orthogonal models'])
xlabel('Longitude')
ylabel('Latitude')
% mapa de color
colormap(h2)
hp=colorbar ('vert');
set(hp, 'ytick',  [.833:.833:5]+.6, 'yticklabel', {'NEU', 'PRO', 'SLC', 'DIA', ...
    'PHA', 'COB'}, 'TickLengt', [0 0])

% Dimensionaless plane U1-U2
subplot(2,2,1)
plot(U2, U1, 'ok');
hold on;
% PFT asignations
for i=1:6
    a=find(PFTunad==i); plot(U2(a), U1(a), '.', 'color', h2(i,:));
end
%a=find(PFT<6);
xlim([min(U2) max(U2)]); ylim([min(U1) max(U1)]);

% orthomodels
mz=10
hold on;
plot(U2S(ai(1,1):ai(1,2)), U1S(ai(1,1):ai(1,2)), '.k','MarkerSize',mz)
plot(U2S(ai(2,1):ai(2,2)), U1S(ai(2,1):ai(2,2)), '.k','MarkerSize',mz)
plot(U2S(ai(3,1):ai(3,2)), U1S(ai(3,1):ai(3,2)),'.k','MarkerSize',mz)
plot(U2S(ai(4,1):ai(4,2)), U1S(ai(4,1):ai(4,2)), '.k','MarkerSize',mz)
plot(U2S(ai(5,1):ai(5,2)), U1S(ai(5,1):ai(5,2)), '.k','MarkerSize',mz)
plot(U2S(ai(6,1):ai(6,2)), U1S(ai(6,1):ai(6,2)), '.k','MarkerSize',mz)
xlabel(['U2 (VarExp.=' sprintf('%3.1f',modevar(2)) '%)']);
ylabel(['U1 (VarExp.=' sprintf('%3.1f',modevar(1)) '%)']);
title('First two orthogonal Modes')

% -----------------------------------------------------------
% PFT estimation using adjusted orthomodels
model=2
[PFTadj, U1, U2, modevar, U1S, U2S, ai, pftnom]=modis_phystwo(Rrs412,Rrs443,Rrs469,Rrs488,Rrs531,Rrs547,Rrs555, aot, chl, model);

figure 
subplot(2,2,2);
pcolor(lon, lat, PFTadj); shading flat;caxis([1 6])
title(['PHYSTWO PFT from adjusted orthogonal models'])
xlabel('Longitude')
ylabel('Latitude')
% mapa de color
colormap(h2)
hp=colorbar ('vert');
set(hp, 'ytick',  [.833:.833:5]+.6, 'yticklabel', {'NEU', 'PRO', 'SLC', 'DIA', ...
    'PHA', 'COB'}, 'TickLengt', [0 0])

% Dimensionaless plane U1-U2
subplot(2,2,1)
plot(U2, U1, 'ok');
hold on;
% PFT asignations
for i=1:6
    a=find(PFTadj==i); plot(U2(a), U1(a), '.', 'color', h2(i,:));
end
%a=find(PFT<6);
xlim([min(U2) max(U2)]); ylim([min(U1) max(U1)]);

% orthomodels
mz=10
hold on;
plot(U2S(ai(1,1):ai(1,2)), U1S(ai(1,1):ai(1,2)), '.k','MarkerSize',mz)
plot(U2S(ai(2,1):ai(2,2)), U1S(ai(2,1):ai(2,2)), '.k','MarkerSize',mz)
plot(U2S(ai(3,1):ai(3,2)), U1S(ai(3,1):ai(3,2)),'.k','MarkerSize',mz)
plot(U2S(ai(4,1):ai(4,2)), U1S(ai(4,1):ai(4,2)), '.k','MarkerSize',mz)
plot(U2S(ai(5,1):ai(5,2)), U1S(ai(5,1):ai(5,2)), '.k','MarkerSize',mz)
plot(U2S(ai(6,1):ai(6,2)), U1S(ai(6,1):ai(6,2)), '.k','MarkerSize',mz)
xlabel(['U2 (VarExp.=' sprintf('%3.1f',modevar(2)) '%)']);
ylabel(['U1 (VarExp.=' sprintf('%3.1f',modevar(1)) '%)']);
title('First two orthogonal Modes')

%% PHYSAT estimations of Phytoplanckton Functional Types 
% 
% The funtion modis_physat.m is an unauthorized implementation of PHYSAT
% method developed by Alvain et al. (2005, 2008, 2012). Please use it as
% reference and cite the original developers. 

clear all
close all

cd /home/geo/Dropbox/PHYSTWO

% Load matrices
load A20140205.L2_LAC_OC.mat

% color map
h2=[ 0.5  0.5 0.5; 0 0 1; 0 1 1; 1 1 0; 1 0 0; .5 0 0];

[PFT, LUTR, nLwr, chl_lutr]=modis_physat(Rrs412,Rrs443,Rrs469,Rrs488,Rrs531,Rrs547,Rrs555, aot, chl, 1);

figure% 
pcolor(lon, lat, PFT); shading flat;caxis([1 6])
colormap( h2)
title(['PHYSAT PFT from nLw^r^e^f'])
xlabel('Longitude')
ylabel('Latitude')
hp=colorbar ('vert');
set(hp, 'ytick',  [.833:.833:5]+.6, 'yticklabel', {'NEU', 'PRO', 'SLC', 'DIA', ...
    'PHA', 'COB'}, 'TickLengt', [0 0])






